@@ -1,5 +1,5 @@
 # defining global variables more centrally
-utils::globalVariables(c(".data", "obs", "from", "to", "name"))
+utils::globalVariables(c(".data", "obs", "from", "to", "name", "A","B","C","D"))
 
 # Helper function for declaring available methods
 available_methods <- function(fun_vctr) {
@@ -16,7 +16,7 @@ available_methods <- function(fun_vctr) {
 
 # Helper function for checking and downloading packages
 thisRequires <- function(pkgname){
-  if (!requireNamespace(pkgname, quietly = TRUE)) {
+  if (!requireNamespace(pkgname, quietly = TRUE) & interactive()) {
     if(utils::askYesNo(msg = paste("The", pkgname, 
                                    "package is required to run this function. Would you like to install", pkgname, "from CRAN?"))) {
       utils::install.packages(pkgname)
@@ -27,7 +27,7 @@ thisRequires <- function(pkgname){
 }
 
 thisRequiresBio <- function(pkgname) {
-  if (!requireNamespace(pkgname, quietly = TRUE)) {
+  if (!requireNamespace(pkgname, quietly = TRUE) & interactive()) {
     if(utils::askYesNo(msg = paste("The", pkgname, 
                                    "package is required to run this function. Would you like to install", pkgname, "from BioConductor?"))) {
   thisRequires("BiocManager")
@@ -41,6 +41,10 @@ thisRequiresBio <- function(pkgname) {
   patchwork::wrap_plots(e1, e2, ...)
 }
 
+seq_nodes <- function(.data){
+  seq.int(net_nodes(.data))
+}
+
 # #' @export
 # `%||%` <- function(x, y) {
 #   if (is_null(x)) y else x
