@@ -57,8 +57,7 @@ node_in_equivalence <- function(.data, census,
                              range = 8L){
   if(missing(.data)) {expect_nodes(); .data <- .G()}
   hc <- switch(match.arg(cluster),
-               hierarchical = cluster_hierarchical(`if`(manynet::is_twomode(.data), 
-                                                        manynet::to_onemode(census), census), 
+               hierarchical = cluster_hierarchical(census, 
                                                       match.arg(distance)),
                concor = cluster_concor(.data, census))
   
@@ -78,8 +77,10 @@ node_in_equivalence <- function(.data, census,
 #' @examples
 #' \donttest{
 #' (nse <- node_in_structural(ison_algebra))
+#' if(require("ggdendro", quietly = TRUE)){
 #' plot(nse)
 #' }
+#' }
 #' @export
 node_in_structural <- function(.data,
                                         k = c("silhouette", "elbow", "strict"),
@@ -101,17 +102,19 @@ node_in_structural <- function(.data,
 #' \donttest{
 #' (nre <- node_in_regular(ison_southern_women,
 #'   cluster = "concor"))
+#' if(require("ggdendro", quietly = TRUE)){
 #' plot(nre)
 #' }
+#' }
 #' @export
 node_in_regular <- function(.data, 
-                                     k = c("silhouette", "elbow", "strict"),
-                                     cluster = c("hierarchical", "concor"),
-                                     distance = c("euclidean", "maximum", "manhattan", 
-                                                  "canberra", "binary", "minkowski"),
-                                     range = 8L){
+                            k = c("silhouette", "elbow", "strict"),
+                            cluster = c("hierarchical", "concor"),
+                            distance = c("euclidean", "maximum", "manhattan", 
+                                         "canberra", "binary", "minkowski"),
+                            range = 8L){
   if(missing(.data)) {expect_nodes(); .data <- .G()}
-  if(manynet::is_twomode(.data)){
+  if(is_twomode(.data)){
     mat <- as.matrix(node_by_quad(.data))
   } else {
     mat <- node_by_triad(.data)
@@ -124,10 +127,14 @@ node_in_regular <- function(.data,
 #' @rdname member_equivalence
 #' @examples
 #' \donttest{
+#' if(require("sna", quietly = TRUE)){
 #' (nae <- node_in_automorphic(ison_southern_women,
 #'   k = "elbow"))
+#' }
+#' if(require("ggdendro", quietly = TRUE)){
 #' plot(nae)
 #' }
+#' }
 #' @export
 node_in_automorphic <- function(.data,
                                          k = c("silhouette", "elbow", "strict"),
